@@ -95,15 +95,29 @@ class HyperVvNicNotFound(NotFound, HyperVException):
     msg_fmt = _("vNic not found: %(vnic_name)s")
 
 
+class HyperVvSwitchNotFound(NotFound, HyperVException):
+    msg_fmt = _("vSwitch not found: %(vswitch_name)s.")
+
+
 class Invalid(OSWinException):
     pass
 
 
+class UnsupportedOperation(Invalid):
+    msg_fmt = _("The operation failed due to the reason: %(reason)s")
+
+
 class InvalidParameterValue(Invalid):
     msg_fmt = _("Invalid parameter value for: "
                 "%(param_name)s=%(param_value)s")
 
 
+class InvalidVMVersion(Invalid):
+    msg_fmt = _("VM '%(vm_name)s' has an invalid version for this operation: "
+                "%(version)s. Version is expected to be between: "
+                "%(min_version)s and %(max_version)s.")
+
+
 class SMBException(OSWinException):
     pass
 
@@ -251,3 +265,13 @@ class ClusterPropertyListEntryNotFound(ClusterPropertyRetrieveFailed):
 
 class ClusterPropertyListParsingError(ClusterPropertyRetrieveFailed):
     msg_fmt = _("Parsing a cluster property list failed.")
+
+
+class SCSIPageParsingError(Invalid):
+    msg_fmt = _("Parsing SCSI Page %(page)s failed. "
+                "Reason: %(reason)s.")
+
+
+class SCSIIdDescriptorParsingError(Invalid):
+    msg_fmt = _("Parsing SCSI identification descriptor failed. "
+                "Reason: %(reason)s.")
