@@ -17,6 +17,7 @@ import collections
 import ctypes
 import os
 import re
+import threading
 
 from oslo_log import log as logging
 
@@ -62,6 +63,8 @@ SCSI_ID_ASSOC_TYPE_DEVICE = 0
 SCSI_ID_CODE_SET_BINARY = 1
 SCSI_ID_CODE_SET_ASCII = 2
 
+_RESCAN_LOCK = threading.Lock()
+
 
 class DiskUtils(baseutils.BaseUtils):
 
@@ -132,9 +135,30 @@ class DiskUtils(baseutils.BaseUtils):
         err_msg = _("Could not find device number for device: %s")
         raise exceptions.DiskNotFound(err_msg % device_name)
 
+    def rescan_disks(self, merge_requests=False):
+        """Perform a disk rescan.
+
+        :param merge_requests: If this flag is set and a disk rescan is
+                               already pending, we'll just wait for it to
+                               finish without issuing a new rescan request.
+        """
+        if merge_requests:
+            rescan_pending = _RESCAN_LOCK.locked()
+            if rescan_pending:
+                LOG.debug("A disk rescan is already pending. "
+                          "Waiting for it to complete.")
+
+            with _RESCAN_LOCK:
+                if not rescan_pending:
+                    self._rescan_disks()
+        else:
+            self._rescan_disks()
+
     @_utils.retry_decorator(exceptions=(exceptions.x_wmi,
                                         exceptions.OSWinException))
-    def rescan_disks(self):
+    def _rescan_disks(self):
+        LOG.debug("Rescanning disks.")
+
         ret = self._conn_storage.Msft_StorageSetting.UpdateHostStorageCache()
 
         if isinstance(ret, collections.Iterable):
@@ -144,6 +168,8 @@ class DiskUtils(baseutils.BaseUtils):
             err_msg = _("Rescanning disks failed. Error code: %s.")
             raise exceptions.OSWinException(err_msg % ret)
 
+        LOG.debug("Finished rescanning disks.")
+
     def get_disk_capacity(self, path, ignore_errors=False):
         norm_path = os.path.abspath(path)
 
@@ -275,3 +301,18 @@ class DiskUtils(baseutils.BaseUtils):
                     selected_identifiers.append(identifier)
 
         return selected_identifiers
+
+    def get_new_disk_policy(self):
+        # This policy is also known as the 'SAN policy', describing
+        # how new disks will be handled.
+        storsetting = self._conn_storage.MSFT_StorageSetting.Get()[1]
+        return storsetting.NewDiskPolicy
+
+    def set_new_disk_policy(self, policy):
+        """Sets the new disk policy, also known as SAN policy.
+
+        :param policy: an integer value, one of the DISK_POLICY_*
+                       values defined in os_win.constants.
+        """
+        self._conn_storage.MSFT_StorageSetting.Set(
+            NewDiskPolicy=policy)
